==> open-cluster-management-discovery-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveredClusterStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DiscoveredClusterStatusBuilder extends DiscoveredClusterStatusFluentImpl<DiscoveredClusterStatusBuilder> implements VisitableBuilder<DiscoveredClusterStatus,DiscoveredClusterStatusBuilder>{
  public DiscoveredClusterStatusBuilder() {
    this(false);
  }
  public DiscoveredClusterStatusBuilder(Boolean validationEnabled) {
    this(new DiscoveredClusterStatus(), validationEnabled);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DiscoveredClusterStatus(), validationEnabled);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent,DiscoveredClusterStatus instance) {
    this(fluent, instance, false);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent,DiscoveredClusterStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatus instance) {
    this(instance,false);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  DiscoveredClusterStatusFluent<?> fluent;
  Boolean validationEnabled;
  public DiscoveredClusterStatus build() {
    DiscoveredClusterStatus buildable = new DiscoveredClusterStatus();
    return buildable;
  }
  
}

==> open-cluster-management-discovery-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveredClusterStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DiscoveredClusterStatusBuilder extends DiscoveredClusterStatusFluent<DiscoveredClusterStatusBuilder> implements VisitableBuilder<DiscoveredClusterStatus,DiscoveredClusterStatusBuilder>{
  public DiscoveredClusterStatusBuilder() {
    this(false);
  }
  public DiscoveredClusterStatusBuilder(Boolean validationEnabled) {
    this(new DiscoveredClusterStatus(), validationEnabled);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DiscoveredClusterStatus(), validationEnabled);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent,DiscoveredClusterStatus instance) {
    this(fluent, instance, false);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatusFluent<?> fluent,DiscoveredClusterStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new DiscoveredClusterStatus());

    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatus instance) {
    this(instance,false);
  }
  public DiscoveredClusterStatusBuilder(DiscoveredClusterStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new DiscoveredClusterStatus());

    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  DiscoveredClusterStatusFluent<?> fluent;
  Boolean validationEnabled;
  public DiscoveredClusterStatus build() {
    DiscoveredClusterStatus buildable = new DiscoveredClusterStatus();
    return buildable;
  }
  
}
